//<!---------------------------------------->
//<!-- AUTHOR     : DIAS MADEIRA LUCA     -->
//<!-- DESC       : ctrl des recettes     -->
//<!-- VERSION    : 1.2                   -->
//<!-- VERS. DATE : 13.05.2022            -->
//<!-- CREA. DATE : 25.02.2022            -->
//<!---------------------------------------->

$(document).ready(function () {
    //creation classe contrôle
    ctrl = new Ctrl();

    //charger script demande
    $.getScript("javascript/service/serviceHTTP.js", function() {
        console.log("serviceHTTP.js charge !");
        const htmlparams = new URLSearchParams(window.location.search);
        var pk_recette = htmlparams.get('ID');
        ctrl.getRecette(chargerRecetteSuccess, chargerRecetteError, 'pk_recipe='+pk_recette);
        ctrl.getUser(getInfoUserSuccess, getInfoUserError);
    });

    //verifier si le user est connecte
    //si oui, modifier la barre du dessus

});

/**
 * classe contenant les méthodes appelées depuis la page ou depuis d'autres fonctions
 */
class Ctrl {
        
    /**
     * constructeur de la classe 
     */
    constructor() {

    }

    /**
     * Méthode permettant de récupérer les informations de la recette
     */
    getRecette(successCallBack, errorCallBack, data) {
        //aller chercher les recettes dans la DB
        getRequest(data, successCallBack, errorCallBack, 'recipeManager.php');
    }

    /**
     * méthode permettant de vérifier si l'utilisateur est connecté ou non
     */
    getUser(successCallBack, errorCallBack) {
        getRequest(null, successCallBack, errorCallBack, 'userManager.php');
    }

    /**
     * méthode permettant à l'utilisateur de se déconnecter et de revenir à la page d'accueil
     */
    deconnexion() {
        //se déconnecter du site
        postRequest('action=deconnexion', deconnectionSuccess, deconnectionError, 'userManager.php');
    }
}

/**
 * méthode agissant lorsque les informations de la recette ont pu être récupérée
 */
function chargerRecetteSuccess(data, text, jqXHR) {
    console.log(data);

    var ingreds = data['ingredients'];
    var stepeus = data['steps'];


    //définir les paramètres uniques
    var pk_recette = data['pk'];


    //définir la partie présentation
    var nomrecette = data['nom'];
    var imagerecette = data['img'];
    var descriptionrecette = data['description'];
    var presentation = '<div class="ONERECIPE_PRESENTATION_BOX">'
                     + '<img alt="' + nomrecette + '" src="' + imagerecette + '">'
                     + '<h1>' + nomrecette + '</h1>'
                     + '<p>' + descriptionrecette + '</p>'
                     + '</div>';

    //definir la partie user
    var nomuser = data['fk_user']['name'];
    var imageuser = data['fk_user']['avatarpath'];
    var pk_user = data['fk_user']['pk'];
    var user = '<table class="ONERECIPE_CREATOR_TABLE">'
             + '<tr>'
             + '<td>'
             + '<a href="./User.html?ID=' + pk_user + '"><img alt="⬤" src="' + imageuser + '"></a>'
             + '</td>'
             + '<td><a href="./User.html?ID=' + pk_user + '">' + nomuser + '</a></td>'
             + '</tr>'
             + '</table>';

    //definir la partie ingrédient
    var ingredients = '<div class="ONERECIPE_INGREDIENT_BOX">'
                    + '<h2>Éléments pour la recette</h2>'
                    + '<ul>';
    for (var i = 0; i < Object.keys(ingreds).length; i++) {
        var quantite = ingreds[i]['quantity'];
        var nom = ingreds[i]['ingredient'];
        var ingred  = '<li>'
                + '<table>'
                + '<tr>'
                + '<td>' + quantite + '</td>'
                + '<td>' + nom + '</td>'
                + '</tr>'
                + '</table>'
                + '<li>';
        ingredients = ingredients + ingred;
    }
    ingredients = ingredients
                + '</ul>'
                + '</div>';

    //definir la partie étapes
    var steps = '<table class="ONERECIPE_STEP_TABLE">'
    for (var i = 1; i <= Object.keys(stepeus).length; i++) {
        var priorityetape = stepeus[i]['priority'];
        var descriptionetape = stepeus[i]['description'];
        var step = '<tr>'
                 + '<td>' + priorityetape + '</td>'
                 + '<td>'
                 + '<p>' + descriptionetape + '</p>'
                 + '</td>'
                 + '</tr>';
        steps = steps + step;
    }
    steps = steps
          + '</table>';

    //creation du string ayant tout le contenu
    var contenu = presentation
                + user
                + ingredients
                + steps;

	$('#ONERECIPE').html(contenu);
}

/**
 * méthode agissant lorsque les informations de la recette n'ont pas pu être récupérée
 */
function chargerRecetteError(request, status, error) {
        //alert("Erreur lors de la lecture des recettes: " + error);
        console.log(error);
        console.log(status);

}

/**
 * méthode agissant lorsqu'un utilisateur a été trouvé dans la session
 */
function getInfoUserSuccess(data, text, jqXHR) {
    //afficher la partie user de la barre de navigation
    console.log(data);
    console.log('it worked');
    var contenu =
'<ul>'+
'   <li id="NAV_LOGO_BOX">'+
'       <a href="./" id="NAV_LOGO_LINK">ReciΠ</a>'+
'   </li>'+
'   <li id="NAV_USER_IMAGE_BOX">'+
'       <img id="NAV_USER_IMAGE_IMG" alt="⬤" src="' + data['avatarpath'] + '">'+
'   </li>'+
'   <li id="NAV_USER_NAME_BOX">'+
'       <a id="NAV_USERNAME_TEXT">' + data['name'] + '</a>'+
'   </li>'+
'   <li id="NAV_DELOG_BOX">'+
'       <a id="NAV_DELOG_LINK" onclick="ctrl.deconnexion();">   ❌</a>'+
'   </li>'+
'   <li class="NAV_PAGELINK_BOX">'+
'       <a class="NAV_PAGELINK_LINK" href="./MyUser.html">MyUser</a>'+
'   </li>'+
'   <li class="NAV_PAGELINK_BOX">'+
'       <a class="NAV_PAGELINK_LINK" href="./Recettes.html">Recettes</a>'+
'   </li>'+
'</ul>';

    $('#NAV').html(contenu);
}

/**
 * méthode agissant lorsqu'il n'y a pas d'utilisateur dans la session ou qu'il n'est pas possible de vérifier cela
 */
function getInfoUserError(request, status, error) {
    console.log(status);
    console.log(error);
    console.log('it FAILED');

    var contenu = 
'<ul>'+
'    <li id="NAV_LOGO_BOX">'+
'       <a href="./" id="NAV_LOGO_LINK">ReciΠ</a>'+
'    </li>'+
'    <li id="NAV_CONNEXION_BOX"><a id="NAV_CONNEXION_LINK" href="./Connexion.html">Connexion</a></li>'+
'    <li class="NAV_PAGELINK_BOX">'+
'       <a class="NAV_PAGELINK_LINK" href="./Recettes.html">Recettes</a>'+
'    </li>'+
'</ul>';

    $('#NAV').html(contenu);
}

/**
 * méthode agissant lorsque la déconnexion de l'utilisateur a fonctionnée
 */
function deconnectionSuccess(data, text, jqXHR) {
    //afficher la partie user de la barre de navigation
    console.log(data);
    console.log('it worked');
    window.location.href = "./Recettes.html";
}

/**
 * méthode agissant lorsque la déconnexion a rencontrée une erreur
 */
function deconnectionError(request, status, error) {
    console.log(status);
    console.log(error);
    console.log('it FAILED');
    alert("UNE ERREUR CATASTROPHIQUE S'EST PASSEE");
    window.location.href = "./Recettes.html";
}
