
<?php
/*
<!--------------------------------------------->
<!-- AUTHOR     : DIAS MADEIRA LUCA          -->
<!-- DESC       : fichier de connex. à la DB -->
<!-- VERSION    : 1.1                        -->
<!-- VERS. DATE : 13.03.2022                 -->
<!-- CREA. DATE : 18.02.2022                 -->
<!--------------------------------------------->
*/
include_once('connexionDBconf.php');
/**
 * Classe servant à communiquer avec la DB
 */
class ConnexionDB {
	private static $_instance = null;
	private $pdo;
	
	/**
     * Fonction d'ouvrir une connexion à la base de données.
     */
    private function __construct() {
    	try {
			$this->pdo = new PDO(DB_TYPE.':host='.DB_HOST.';dbname='.DB_NAME, DB_USER, DB_PASS, array(PDO::MYSQL_ATTR_INIT_COMMAND => 'SET NAMES utf8'));
		}catch (PDOException $e) {
    		print "Erreur !: " . $e->getMessage() . "<br/>";
    		die();
		}
	}

    /**
     * obtiens une nouvelle instance de la classe afin de ne pas avoir plusieurs connexions ouvertes
     */
    public static function getInstance() {
        if (is_null(self::$_instance)) {
            self::$_instance = new connexionDB();
        }
        return self::$_instance;
    }

    /**
     * détruit l'instance
     */
    public function __destruct() {
        $this->pdo = null;
    }

    /**
     * permet d'exécuter une requête dont on retourne le nombre de ligne
     */
	public function executeQuery($query, $params) {
		try {
            $queryPrepared = $this->pdo->prepare($query);
            $queryPrepared->execute($params);
            return $queryPrepared->rowCount();
        } catch (PDOException $e) {
            print "Erreur !: " . $e->getMessage() . "<br/>";
            die();
        }
	}

    /**
     * permet d'exécuter une requête dont on retourne toutes les lignes
     */
	public function selectQuery($query, $params) {
		try {
            $queryPrepared = $this->pdo->prepare($query);
            $queryPrepared->execute($params);
            return $queryPrepared->fetchAll();
        } catch (PDOException $e) {
            print "Erreur !: " . $e->getMessage() . "<br/>";
            die();
        }
	}

    /**
     * Fonction permettant d'obtenir le dernier id inséré.
     * 
     * @param String $table. la table où a été inséré l'objet. 
     * @return int: l'id du dernier élément inséré.
     */
    public function getLastId($table) {
        try {
            $lastId = $this->pdo->lastInsertId($table);
            return $lastId;
        } catch (PDOException $e) {
            print "Erreur !: " . $e->getMessage() . "<br/>";
            die();
        }
    }

}

?>
