<?php 
/*
<!---------------------------------------->
<!-- AUTHOR     : DIAS MADEIRA LUCA     -->
<!-- DESC       : managerdb des recettes-->
<!-- VERSION    : 1.2                   -->
<!-- VERS. DATE : 13.05.2022            -->
<!-- CREA. DATE : 18.02.2022            -->
<!---------------------------------------->
*/
	include_once('../wrk/ConnexionDB.php');
    include_once('../bean/Ingredient.php');
    include_once('../bean/Step.php');
    include_once('../bean/Recipe.php');
    include_once('../bean/User.php');
        
    /**
     * classe servant à gérer les recettes (et ingrédients et étapes) de la DB
     */
	class recipeDBManager
	{
	    /**
	     * méthode servant à ajouter un nouvel ingrédient dans la DB et retourner la pk
	     */
		public function addIngredient($name) {

            $answer = false;
            
            //0. sécurisation HTTP des paramètres reçu.
            $cname = htmlspecialchars($name);

            //1. vérifier si un ingrédient du même nom n'existe pas déjà
            $checkingQuery = ConnexionDB::getInstance()->selectQuery(
               'SELECT count(*) 
                FROM diasmadeiral_151_ldm_db_recipe.t_ingredient ingred
                WHERE ingred.Name = :name ;',
                array('name' => $cname)
            );
            
            if ($checkingQuery) {
                if($checkingQuery[0][0] == '0') {
                    //1b0. si non, en créer un avec le nom
                    $params = array('name' => $cname);
                    $query = ConnexionDB::getInstance()->executeQuery(
                        'INSERT INTO diasmadeiral_151_ldm_db_recipe.t_ingredient (Name)
                         VALUES (:name);', $params
                    );
                    
                    //1b1. puis aller chercher sa pk_ingredient et la retourner
                    if($query == 1) {
                        $answer = ConnexionDB::getInstance()-> getLastId('diasmadeiral_151_ldm_db_recipe.t_ingredient');
                    }
                } else {
                    //1a. si oui, ne pas en ajouter un, et retourner la pk_ingredient de l'ingrédient existant
                    $existsQuery = ConnexionDB::getInstance()->selectQuery(
                        'SELECT ingred.PK_Ingredient
                        FROM diasmadeiral_151_ldm_db_recipe.t_ingredient ingred
                        WHERE ingred.Name = :name ;',
                        array('name' => $cname)
                    );
                    $answer = $existsQuery[0][0];
                }
                
            }
            return $answer;
        }
        
        /**
         * méthode servant à ajouter une nouvelle recette dans la db et retourner la pk
         */
        public function addRecipe($fk_user, $name, $description, $image) {
            $answer = false;

            //0. sécurisation HTTP des paramètres reçu.
            $cfk_user = htmlspecialchars($fk_user);
            $cname = htmlspecialchars($name);
            $cdescription = htmlspecialchars($description);
            $cimage = htmlspecialchars($image);

            //1. ajouter la recette dans la base de données
            $params = array('fkuser' => $cfk_user, 'name' => $cname, 'description' => $cdescription, 'image' => $cimage);
            $query = ConnexionDB::getInstance()->executeQuery(
                'INSERT INTO diasmadeiral_151_ldm_db_recipe.t_recipe (FK_User, Name, Description, Image)
                 VALUES ( :fkuser , :name , :description , :image );
                ', $params
            );

            //2. aller chercher la recette dans la db et retourner sa pk_recipe
            $answer = ConnexionDB::getInstance()->getLastId('diasmadeiral_151_ldm_db_recipe.t_recipe');

            return $answer;
        }
        
        /**
	     * méthode servant à ajouter un nouvel lien recette-ingrédient dans la DB
	     */
        public function addRecipeIngredient($fpk_recipe, $fpk_ingredient, $quantity) {
            $answer = false;

            //0. sécurisation HTTP des paramètres reçu.
            $cfpk_recipe = htmlspecialchars($fpk_recipe);
            $cfpk_ingredient = htmlspecialchars($fpk_ingredient);
            $cquantity = htmlspecialchars($quantity);

            //1. vérifier si un lien entre la recette et l'ingrédient n'existe pas déjà
            $checkingQuery = ConnexionDB::getInstance()->selectQuery(
               'SELECT count(*) 
                FROM diasmadeiral_151_ldm_db_recipe.tr_recipe_ingredient TR
                WHERE ( (TR.FPK_Ingredient = :fpki) AND (TR.FPK_Recipe = :fpkr) );',
                array('fpki' => $cfpk_ingredient, 'fpkr' => $cfpk_recipe)
            );

            
            if ($checkingQuery) {
                if($checkingQuery[0][0] == '0') {
                    
                    //1b. si non, en ajouter un

                    $params = array('fpki' => $cfpk_ingredient, 'fpkr' => $cfpk_recipe, 'quantity' => $cquantity);
                    $query = ConnexionDB::getInstance()->executeQuery(
                        'INSERT INTO diasmadeiral_151_ldm_db_recipe.tr_recipe_ingredient (FPK_Ingredient, FPK_Recipe, Quantity)
                         VALUES (:fpki , :fpkr , :quantity);', $params
                    );
                    
                    if($query == 1) {
                        $answer = true;
                    }

                } else {
                    //1a. si oui, ne pas en ajouter un, et simplement mettre à jour la quantité
                    
                    $params = array('fpki' => $cfpk_ingredient, 'fpkr' => $cfpk_recipe, 'quantity' => $cquantity);
                    $updateQuery = ConnexionDB::getInstance()->executeQuery(
                        'UPDATE diasmadeiral_151_ldm_db_recipe.tr_recipe_ingredient
                         SET Quantity = :quantity
                         WHERE ( (TR.FPK_Ingredient = :fpki) AND (TR.FPK_Recipe = :fpkr) ); ', $params);
                    
                    if($updateQuery == 1) {
                        $answer = true;
                    }
                }
            }

            //retourner true si c'est bien passé.
            return $answer;
        }
        
        /**
	     * méthode servant à ajouter une nouvelle  dans la DB et retourner la pk
	     */
        public function addStep($fk_recipe, $description, $priority) {

            $answer = -666;

            //0. sécurisation HTTP des paramètres reçu.
            $cfk_recipe = htmlspecialchars($fk_recipe);
            $cpriority = htmlspecialchars($priority);
            $cdescription = htmlspecialchars($description);


            //1. ajouter l'étape dans la db
            $params = array('priority' => $cpriority, 'fk' => $cfk_recipe, 'desc' => $cdescription);
            $query = ConnexionDB::getInstance()->executeQuery(
                'INSERT INTO diasmadeiral_151_ldm_db_recipe.t_step (Priority, Description, FK_Recipe)
                 VALUES (:priority , :desc , :fk);', $params
            );

            if($query == 1) {
                //2. aller chercher la pk de l'étape et la retourner
                $answer = ConnexionDB::getInstance()-> getLastId('diasmadeiral_151_ldm_db_recipe.t_step');
            }
            
            return $answer;
        }
        
        /**
         * Méthode servant à supprimer une recette après qu'il fut prouvé que l'utilisateur connecté est son propriétaire
         */
        public function deleteRecipe($pk_recipe, $fk_user) {
            $answer = false;

            //1. vérifier si la recette existe
            $checkingQuery = ConnexionDB::getInstance()->selectQuery(
               'SELECT count(*) 
                FROM diasmadeiral_151_ldm_db_recipe.t_recipe recette
                WHERE (recette.PK_Recipe = :pk AND recette.FK_User = :fk);',
                array('pk' => $pk_recipe, 'fk' => $fk_user)
            );
            
            if ($checkingQuery) { 
                if($checkingQuery[0][0] == '0') { 
                    //1a. si non, retourner 'does not exist'
                    $answer = 'does not exist';
                } else {
                    //1b. si oui, supprimer la recette
                    $query = ConnexionDB::getInstance()->executeQuery(
                        'DELETE FROM diasmadeiral_151_ldm_db_recipe.t_recipe
                         WHERE PK_Recipe = :pk ;', array('pk' => $pk_recipe)
                    );
                    
                    if($query == 1) {
                        $answer = true;
                    }
                }
            }
            
            //1b2. si tout a marché, retourner true, sinon false
            return $answer;
        }
        
        /**
         * Méthode servant à supprimer une relation ingrédient-recette lors de la modification de cette dernière
         */
        public function deleteRecipeIngredientLink($fpk_recipe, $fpk_ingredient) {
            $answer = false;

            //1. vérifier si le lien existe
            $checkingQuery = ConnexionDB::getInstance()->selectQuery(
               'SELECT count(*) 
                FROM diasmadeiral_151_ldm_db_recipe.tr_recipe_ingredient
                WHERE (FPK_Recipe = :fpkr AND FPK_Ingredient = :fpki );',
                array('fpkr' => $fpk_recipe, 'fpki' => $fpk_ingredient)
            );
            
            if ($checkingQuery) { 
                if($checkingQuery[0][0] == '0') {
                    //1a. si non, retourner 'does not exist'
                    $answer = 'does not exist';
                } else {
                    //1b0. si oui, supprimer le lien
                    $query = ConnexionDB::getInstance()->executeQuery(
                        'DELETE FROM diasmadeiral_151_ldm_db_recipe.tr_recipe_ingredient
                         WHERE (FPK_Recipe = :fpkr AND FPK_Ingredient = :fpki ) ;', array('fpkr' => $fpk_recipe, 'fpki' => $fpk_ingredient)
                    );
                    
                    if($query == 1) {
                        $answer = true;
                    }
                }
            }

            //1b1. retourner true ou false selon si la suppression a marché
            return $answer;
        }
        
        /**
         * Méthode servant à supprimer une étape d'une recette lors de la modification de cette dernière
         */
        public function deleteStep($pk_step) {
            $answer = false;
            
            //1. vérifier si la step existe
            $checkingQuery = ConnexionDB::getInstance()->selectQuery(
               'SELECT count(*) 
                FROM diasmadeiral_151_ldm_db_recipe.t_step stepe
                WHERE stepe.PK_Step = :pk ;',
                array('pk' => $pk_step)
            );
            
            if ($checkingQuery) { 
                if($checkingQuery[0][0] == '0') { 
                    //1a. si non, retourner 'does not exist'
                    $answer = 'does not exist';
                } else {
                    //1b. si oui, supprimer la step
                    $query = ConnexionDB::getInstance()->executeQuery(
                        'DELETE FROM diasmadeiral_151_ldm_db_recipe.t_step
                         WHERE PK_Step = :pk ;', array('pk' => $pk_step)
                    );
                    
                    if($query == 1) {
                        $answer = true;
                    }
                }
            }
            
            //1b2. si tout a marché, retourner true, sinon false
            return $answer;
        }
        
        /**
         * méthode servant à récupérer TOUTES les recettes de la DB, recherche d'abord les recette avec ingrédients puis celles sans
         */
        public function getAllRecipes() {

            $answer = false;

            //1. chercher dans la db si les recettes liés aux ingrédients
            $recettesSansEtapes = array();
            $count = 0;
            $query = ConnexionDB::getInstance()->selectQuery(
            'SELECT recette.PK_Recipe pk_recette, recette.FK_User fk_user, recette.Name name, recette.Description description, recette.Image image, TR.Quantity quantity, ingredient.PK_Ingredient pk_ingredient, ingredient.Name ingredient FROM diasmadeiral_151_ldm_db_recipe.t_recipe recette INNER JOIN diasmadeiral_151_ldm_db_recipe.tr_recipe_ingredient TR 
             ON TR.FPK_Recipe = recette.PK_Recipe
             INNER JOIN diasmadeiral_151_ldm_db_recipe.t_ingredient ingredient
             ON TR.FPK_Ingredient = ingredient.PK_Ingredient;', null
            );

            if($query) {
            
            
                foreach($query as $data){
                    //si la pk_recipe existe déjà dans la liste de recette, ajouter l'ingrédient
                    $recipeAlreadyInList = false;
                    $whichRecipe;
                    foreach($recettesSansEtapes as $recette) {
                        if($recette->getPK_Recipe() === $data['pk_recette']) {
                            $recipeAlreadyInList = true;
                            $whichRecipe = $recette;
                            break;
                        }
                    }
                    if($recipeAlreadyInList) {
                        $ingredients = $whichRecipe->getIngredients();
                        $newIngredient = new Ingredient($data['pk_ingredient'], $data['ingredient'], $data['quantity']);
                        array_push($ingredients, $newIngredient);
                        $whichRecipe->setIngredients($ingredients);
                    }
                    //sinon en créer un nouveau
                    else {
                        $uneRecette = new Recipe(
                            $data['pk_recette'],
                            $data['name'],
                            $data['image'],
                            $data['description'],
                            $data['fk_user'],
                            "steps",
                            array(new Ingredient($data['pk_ingredient'], $data['ingredient'], $data['quantity']))
                            
                        );
                        $recettesSansEtapes[$count++] = $uneRecette;
                    }
                }
                
                $query2 = ConnexionDB::getInstance()->selectQuery(
                    'SELECT recette.PK_Recipe pk_recette, recette.FK_User fk_user, recette.Name name, recette.Description description, recette.Image image FROM diasmadeiral_151_ldm_db_recipe.t_recipe recette;', null
                );
                
                if(!empty($query2)) {
                    foreach($query2 as $data){
                        //si la pk_recipe existe déjà dans la liste de recette, rien faire
                        $recipeAlreadyInList = false;
                        $whichRecipe;
                        foreach($recettesSansEtapes as $recette) {
                            if($recette->getPK_Recipe() === $data['pk_recette']) {
                                $recipeAlreadyInList = true;
                                $whichRecipe = $recette;
                                break;
                            }
                        }
                        if(!$recipeAlreadyInList) {
                            $uneRecette = new Recipe(
                                $data['pk_recette'],
                                $data['name'],
                                $data['image'],
                                $data['description'],
                                $data['fk_user'],
                                "steps",
                                array(new Ingredient("NONE", "Pas d'ingrédients", ""))
                                
                            );
                            $recettesSansEtapes[$count++] = $uneRecette;
                        }
                    }
                }
                
                //2. retourner la réponse formatée en JSON
                $answer = json_encode($recettesSansEtapes);
            }

            return $answer;

        }
        
        /**
         * méthode permettant de récupérer une recette unique de la db
         */
        public function getRecipe($pk_recipe) {
            $answer = false;

            //1. chercher dans la db la recette seule, accompagnée de son user.

            $firstQuery = ConnexionDB::getInstance()->selectQuery(
            'SELECT recette.PK_Recipe pk_recette, recette.FK_User fk_user, recette.Name name, recette.Description description, recette.Image image, user.AvatarPath userimage, user.Name username FROM diasmadeiral_151_ldm_db_recipe.t_recipe recette 
            INNER JOIN diasmadeiral_151_ldm_db_recipe.t_user user
            ON user.PK_User = recette.FK_User
            WHERE recette.PK_Recipe = :pk_recette;', array('pk_recette' => $pk_recipe)
            );

            $data1 = $firstQuery;

            //2. chercher dans la db les ingrédients (et quantité) de la recette
            $secondQuery = ConnexionDB::getInstance()->selectQuery(
            'SELECT ingredient.Name ingredient, ingredient.PK_Ingredient pk_ingredient, TR.Quantity quantity FROM diasmadeiral_151_ldm_db_recipe.t_ingredient ingredient
            INNER JOIN diasmadeiral_151_ldm_db_recipe.tr_recipe_ingredient TR
            ON ingredient.PK_Ingredient = TR.FPK_Ingredient
            WHERE TR.FPK_Recipe = :pk_recette;', array('pk_recette' => $pk_recipe)
            );

            $data2 = $secondQuery;

            //3. chercher dans la db les étapes de la recette
            $thirdQuery = ConnexionDB::getInstance()->SelectQuery(
            'SELECT step.PK_Step pk_step, step.FK_Recipe fk_recipe, step.Priority priority, step.Description stepdescription FROM diasmadeiral_151_ldm_db_recipe.t_step step
            WHERE step.FK_Recipe = :pk_recette;', array('pk_recette' => $pk_recipe)
            );

            $data3 = $thirdQuery;

            //check si les recherche ont foirés
            if ($data1 && $data2 && $data3) {
                if( !empty($data1) && !empty($data2) && !empty($data3) ) {

                    //4. grouper les ingrédients en un array
                    $ingredcount = 0;
                    $ingredients = array();
                    foreach($data2 as $data) {
                        $ingredients[$ingredcount++] = new Ingredient($data['pk_ingredient'], $data['ingredient'], $data['quantity']);
                    }

                    //5. grouper les étapes en un array
                    $stepcount = 0;
                    $steps = array();
                    foreach($data3 as $data) {
                        $steps[$data['priority']] = new Step($data['pk_step'], $data['priority'], $data['stepdescription'], $data['fk_recipe']);
                    }

                    
                    $user;
                    $recipe;
                    foreach($data1 as $data) {

                        //6. utiliser les informations du user pour en créer un bean
                        $user = new User($data['fk_user'], null, null, $data['username'], null, $data['userimage']);

                        //7. créer un bean recette
                        $recipe = new Recipe(
                            $data['pk_recette'],
                            $data['name'],
                            $data['image'],
                            $data['description'],
                            $user,
                            $steps,
                            $ingredients
                        );

                        //8. le transformer en JSON
                        $answer = json_encode($recipe);
                    }
                } else {
                    $answer = 'invalid ID';
                }
            }

            return $answer;

            
        }
        
        /**
         * méthode permettant de récupérer les recettes d'un seul utilisateur
         */
        public function getRecipeOfUser($pk_user) {
            $answer = false;

            //1. chercher dans la db si les recettes liés aux ingrédients
            $recettesSansEtapes = array();
            $canFormat = false;
            $count = 0;
            $query = ConnexionDB::getInstance()->selectQuery(
            'SELECT recette.PK_Recipe pk_recette, recette.FK_User fk_user, recette.Name name, recette.Description description, recette.Image image, TR.Quantity quantity, ingredient.PK_Ingredient pk_ingredient, ingredient.Name ingredient FROM diasmadeiral_151_ldm_db_recipe.t_recipe recette 
             INNER JOIN diasmadeiral_151_ldm_db_recipe.tr_recipe_ingredient TR 
             ON TR.FPK_Recipe = recette.PK_Recipe
             INNER JOIN diasmadeiral_151_ldm_db_recipe.t_ingredient ingredient
             ON TR.FPK_Ingredient = ingredient.PK_Ingredient
             WHERE fk_user = :pkuser ;', array('pkuser' => $pk_user)
            );

            if($query) {
              if(!empty($query)) {
            
                foreach($query as $data){
                    //si la pk_recipe existe déjà dans la liste de recette, ajouter l'ingrédient
                    $recipeAlreadyInList = false;
                    $whichRecipe;
                    foreach($recettesSansEtapes as $recette) {
                        if($recette->getPK_Recipe() === $data['pk_recette']) {
                            $recipeAlreadyInList = true;
                            $whichRecipe = $recette;
                            break;
                        }
                    }
                    if($recipeAlreadyInList) {
                        $ingredients = $whichRecipe->getIngredients();
                        $newIngredient = new Ingredient($data['pk_ingredient'], $data['ingredient'], $data['quantity']);
                        array_push($ingredients, $newIngredient);
                        $whichRecipe->setIngredients($ingredients);
                    }
                    //sinon en créer un nouveau
                    else {
                        $uneRecette = new Recipe(
                            $data['pk_recette'],
                            $data['name'],
                            $data['image'],
                            $data['description'],
                            $data['fk_user'],
                            "steps",
                            array(new Ingredient($data['pk_ingredient'], $data['ingredient'], $data['quantity']))
                            
                        );
                        $recettesSansEtapes[$count++] = $uneRecette;
                    }
                }
                

                

                
                //2. retourner la réponse formatée en JSON
                $canFormat = true;
              } else {
                $answer = 'invalid ID';
              }

            }

            $query2 = ConnexionDB::getInstance()->selectQuery(
                'SELECT recette.PK_Recipe pk_recette, recette.FK_User fk_user, recette.Name name, recette.Description description, recette.Image image FROM diasmadeiral_151_ldm_db_recipe.t_recipe recette 
                 WHERE fk_user = :pkuser ;', array('pkuser' => $pk_user)
            );

            if($query2) {
                if(!empty($query2)) {
                    foreach($query2 as $data){
                        //si la pk_recipe existe déjà dans la liste de recette, rien faire
                        $recipeAlreadyInList = false;
                        $whichRecipe;
                        foreach($recettesSansEtapes as $recette) {
                            if($recette->getPK_Recipe() === $data['pk_recette']) {
                                $recipeAlreadyInList = true;
                                $whichRecipe = $recette;
                                break;
                            }
                        }
                        if(!$recipeAlreadyInList) {
                            $uneRecette = new Recipe(
                                $data['pk_recette'],
                                $data['name'],
                                $data['image'],
                                $data['description'],
                                $data['fk_user'],
                                "steps",
                                array(new Ingredient("NONE", "Pas d'ingrédients", ""))
                                
                            );
                            $recettesSansEtapes[$count++] = $uneRecette;
                        }
                    }
                    $canFormat = true;
                }
                
            }

            if($canFormat) {
                $answer = json_encode($recettesSansEtapes);
            }
            return $answer;
        }
        
        /**
         * méthode servant à mettre à jour les informations basiques d'une recette dont l'utilisatuer est celui de la session
         */
        public function updateRecipe($pk_recipe, $fk_user, $image, $description, $name) {
            $answer = false;

            //0. sécurisation HTTP des paramètres reçu.
            $cpk_recipe = htmlspecialchars($pk_recipe);
            $cfk_user = htmlspecialchars($fk_user);
            $cname = htmlspecialchars($name);
            $cdescription = htmlspecialchars($description);
            $cimage = htmlspecialchars($image);

            //1. vérifier si, en cherchant dans la db avec la pk et la fk, que la recette existe
            //   (la fk pour empêcher des modifications frauduleuse)
            $checkingQuery = ConnexionDB::getInstance()->selectQuery(
               'SELECT count(*) 
                FROM diasmadeiral_151_ldm_db_recipe.t_recipe recette
                WHERE (recette.PK_Recipe = :pk AND recette.FK_User = :fk);',
                array('pk' => $cpk_recipe, 'fk' => $cfk_user)
            );
            
            if ($checkingQuery) { 
                if($checkingQuery[0][0] == '0') { 
                    //1a. si non, retourner 'does not exist'
                    $answer = 'does not exist';
                } else {
                    //1b0. si oui, mettre à jour dans la db la recette
                    $query = ConnexionDB::getInstance()->executeQuery(
                        'UPDATE diasmadeiral_151_ldm_db_recipe.t_recipe
                         SET Name = :name , Description = :desc , Image = :img
                         WHERE (recette.PK_Recipe = :pk AND recette.FK_User = :fk);', array('pk' => $cpk_recipe, 'fk' => $cfk_user , 'name' => $cname , 'desc' => $cdescription , 'img' => $cimage)
                    );
                    
                    if($query == 1) {
                        $answer = true;
                    }
                }
            }
            
            //1b1. retourner true ou false selon si la mise à jour a marché
            return $answer;
        }
        
        /**
         * méthode servant à mettre à jour la quantité d'une relation ingrédient-recette
         */
        public function updateRecipeIngredientLink($fpk_recipe, $fpk_ingredient, $quantity) {
            $answer = false;
            
            //0. sécurisation HTTP des paramètres reçu.
            $cfpk_recipe = htmlspecialchars($fpk_recipe);
            $cfpk_ingredient = htmlspecialchars($fpk_ingredient);
            $cquantity = htmlspecialchars($quantity);



            //1. vérifier si, en cherchant dans la db avec les fpk, que le lien existe
            $checkingQuery = ConnexionDB::getInstance()->selectQuery(
               'SELECT count(*) 
                FROM diasmadeiral_151_ldm_db_recipe.tr_recipe_ingredient
                WHERE (FPK_Recipe = :fpkr AND FPK_Ingredient = :fpki );',
                array('fpkr' => $fpk_recipe, 'fpki' => $fpk_ingredient)
            );
            
            if ($checkingQuery) { 
                if($checkingQuery[0][0] == '0') {
                    //1a. si non, retourner 'does not exist'
                    $answer = 'does not exist';
                } else {
                    //1b0. si oui, mettre à jour le lien dans la db
                    $query = ConnexionDB::getInstance()->executeQuery(
                        'UPDATE diasmadeiral_151_ldm_db_recipe.tr_recipe_ingredient
                         SET Quantity = :quantity
                         WHERE (FPK_Recipe = :fpkr AND FPK_Ingredient = :fpki ) ;', array('fpkr' => $cfpk_recipe, 'fpki' => $cfpk_ingredient, 'quantity' =>$cquantity)
                    );
                    
                    if($query == 1) {
                        $answer = true;
                    }
                }
            }
                    
            //1b1. retourner true ou false selon si la mise à jour a marché
            return $answer;
        }
        
        /**
         * méthode servant à mettre à jour la priorité et la description d'une étape
         */
        public function updateStep($pk_step, $priority, $description) {
            $answer = false;
            
            //0. sécurisation HTTP des paramètres reçu.
            $cpk_step = htmlspecialchars($pk_step);
            $cpriority = htmlspecialchars($priority);
            $cdescription = htmlspecialchars($description);
            
            //1. vérifier si, en cherchant dans la db avec la pk, que l'étape existe
            $checkingQuery = ConnexionDB::getInstance()->selectQuery(
               'SELECT count(*) 
                FROM diasmadeiral_151_ldm_db_recipe.t_step stepe
                WHERE stepe.PK_Step = :pk ;',
                array('pk' => $cpk_step)
            );
            
            if ($checkingQuery) { 
                if($checkingQuery[0][0] == '0') { 
                    //1a. si non, retourner 'does not exist'
                    $answer = 'does not exist';
                } else {
                    //1b0. si oui, mettre à jour l'étape dans la db
                    $query = ConnexionDB::getInstance()->executeQuery(
                        'UPDATE diasmadeiral_151_ldm_db_recipe.t_step
                         SET Priority = :priority , Description = :desc
                         WHERE PK_Step = :pk ;', array('pk' => $cpk_step, 'priority' => $cpriority, 'desc' => $cdescription)
                    );
                    
                    if($query == 1) {
                        $answer = true;
                    }
                }
            }
            
            //1b2. si tout a marché, retourner true, sinon false
            return $answer;
        }
        
        /**
         * méthode servant à récupérer les recettes de l'utilisateur de la session
         */
        public function getRecipeOfMyUser($pk_user) {
            

            $answer = false;

            //1. chercher dans la db si les recettes liés aux ingrédients
            $recettesSansEtapes = array();
            $count = 0;
            $query = ConnexionDB::getInstance()->selectQuery(
            'SELECT recette.PK_Recipe pk_recette, recette.FK_User fk_user, recette.Name name FROM diasmadeiral_151_ldm_db_recipe.t_recipe recette 
             WHERE fk_user = :pkuser ;', array('pkuser' => $pk_user)
            );

            if($query) {
              if(!empty($query)) {
            
                foreach($query as $data){
                    $uneRecette = new Recipe(
                        $data['pk_recette'],
                        $data['name'],
                        ""/*$data['image']*/,
                        ""/*$data['description']*/,
                        $data['fk_user'],
                        "steps",
                        "ingredients"
                    );
                    $recettesSansEtapes[$count++] = $uneRecette;
                }
              }	
                
                //2. retourner la réponse formatée en JSON
                $answer = json_encode($recettesSansEtapes);
            } else {
                $answer = 'invalid ID';
            }
            
            return $answer;
        }
	}
?>