<?php 

/*
<!---------------------------------------->
<!-- AUTHOR     : DIAS MADEIRA LUCA     -->
<!-- DESC       : manager db des users  -->
<!-- VERSION    : 1.0                   -->
<!-- VERS. DATE : 10.03.2022            -->
<!-- CREA. DATE : 18.02.2022            -->
<!---------------------------------------->
*/
	include_once('../wrk/ConnexionDB.php');
    include_once('../bean/User.php');
    
    /**
     * classe servant à gérer les accès à la DB qui concernent un utilisateur
     */
	class userDBManager
	{
	    /**
	     * ajoute un utilisateur dans la db et retourne sa pk
	     */
		public function addUser($name, $email, $password) {

            $answer = false;

            //0. sécurisation HTTP des paramètres reçu.
            $cname = htmlspecialchars($name);
            $cemail = htmlspecialchars($email);
            $cpassword = htmlspecialchars($password);


            //1. vérifier si un user du même email ou username n'existe pas déjà
            $checkingQuery = ConnexionDB::getInstance()->selectQuery(
               'SELECT count(*) 
                FROM diasmadeiral_151_ldm_db_recipe.t_user user
                WHERE ((user.Email = :useremail) OR (user.Name = :username));',
                array('username' => $cname, 'useremail' => $cemail)
            );

            
            if ($checkingQuery) {
                if($checkingQuery[0][0] == '0') {
                    
                    //1b0. si non, en créer un avec le nom, l'email et le password
                    $defaultavatarpath = 'https://i.pinimg.com/originals/60/99/f3/6099f305983371dadaceae99f5c905bf.png';
                    $passwordhashed = password_hash($cpassword, PASSWORD_DEFAULT);

                    $params = array('name' => $cname, 'email' => $cemail, 'password' => $passwordhashed, 'image' => $defaultavatarpath);
                    $query = ConnexionDB::getInstance()->executeQuery(
                        '
                         INSERT INTO diasmadeiral_151_ldm_db_recipe.t_user (Name, Email, Password, AvatarPath)
                         VALUES ( :name , :email , :password , :image );
                         
                        ', $params
                    );


                    //si requête réussie
                    if($query == 1) {
                        //1b1. puis aller chercher sa pk_user 
                        $answer = ConnexionDB::getInstance()-> getLastId('diasmadeiral_151_ldm_db_recipe.t_user');
                    }
                } else {
                    //1a. si oui, ne pas en ajouter un, et retourner 'email or username already taken'
                    $answer = 'email or username already taken';
                }
            }
            
            return $answer;
        }
        
        /**
         * retourne les informations publiques d'un utilisateur
         */
        public function getUser($pk_user) {
            $answer = false;

            //1. chercher le user dans la db 
            $query = ConnexionDB::getInstance()->selectQuery(
               'SELECT user.PK_User pk, user.Name name, user.Description description, user.AvatarPath image
                FROM diasmadeiral_151_ldm_db_recipe.t_user user
                WHERE user.PK_User = :pkuser ;', array('pkuser' => $pk_user)
            );

            if($query) {
                if(!empty($query)) {

                    //créer un Bean du user
                    $user;
                    foreach($query as $data) {
                        $user = new User(
                            $data['pk'],
                            null,
                            $data['description'],
                            $data['name'],
                            null,
                            $data['image']
                        );
                    }

                    //le formater en JSON
                    $answer = json_encode($user);

                } else {
                    $answer = 'invalid ID';
                }
            }

            return $answer;
        
        }
        
        /**
         * méthode servant à mettre à jour la description et la photo de profil de l'utilisateur connecté
         */
        public function updateUser($pk_user, $description, $avatarPath) {
            $answer = false;
            
            //0. sécurisation HTTP des paramètres reçu.
            $cpk_user = htmlspecialchars($pk_user);
            $cdescription = htmlspecialchars($description);
            $cavatarPath = htmlspecialchars($avatarPath);


            //1. vérifier si, en cherchant dans la db avec la pk, que le user existe
            $checkingQuery  = ConnexionDB::getInstance()->selectQuery(
               'SELECT count(*)
                FROM diasmadeiral_151_ldm_db_recipe.t_user user
                WHERE user.PK_User = :pkuser ;', array('pkuser' => $cpk_user)
            );
            
            if ($checkingQuery) { 
                if($checkingQuery[0][0] == '0') {
                    //1a. si non, retourner 'does not exist'
                    $answer = 'does not exist';
                } else {
                    //1b0. si oui, mettre à jour le user dans la db
                    $query = ConnexionDB::getInstance()->executeQuery(
                        'UPDATE diasmadeiral_151_ldm_db_recipe.t_user user
                         SET Description = :desc , AvatarPath = :img
                         WHERE user.PK_User = :pk ;', array('pk' => $cpk_user, 'desc' => $cdescription, 'img' =>$cavatarPath)
                    );
                    
                    if($query == 1) {
                        $answer = true;
                    }
                }
            }

            //1b1. retourner true ou false selon si la mise à jour a marchée
            return $answer;
        }
	}
?>